import * as SNS from '@aws-sdk/client-sns';
import { ILogger } from 'typescript-ilogger';
import { ISNSHelper } from './interface';
import { BaseClass } from 'typescript-helper-functions';
import { MessageAttributeValue } from './any';
/**
 * SNS Helper
 */
export declare class SNSHelper extends BaseClass implements ISNSHelper {
    /**
     * AWS Repository for SNS
     */
    private Repository;
    /**
     * Initializes new instance of SNSHelper
     * @param logger {ILogger} Injected logger
     * @param repository {SNS.SNS} Injected Repository. A new repository will be created if not supplied
     * @param options {SNS.SNSClientConfig} Injected configuration if a Repository is supplied
     */
    constructor(logger: ILogger, repository?: SNS.SNS, options?: SNS.SNSClientConfig);
    /**
     * Publish a message
     * @param topicArn {string} Topic ARN to publish to
     * @param subject {string} Subject of message to send
     * @param message {string} Contents of message to send
     * @param messageAttributes {MessageAttributeValue} Attributes to give the message to send
     */
    PublishAsync(topicArn: string, subject: string, message: string, messageAttributes?: MessageAttributeValue): Promise<SNS.PublishResponse>;
}
